Compute standard error estimates for estimates of variable importance.

vimp_se(
  eif_full,
  eif_reduced,
  cross_fit = TRUE,
  sample_split = TRUE,
  na.rm = FALSE,
  use_square = FALSE
)

Arguments

eif_full

the estimated efficient influence function (EIF) based on the full set of covariates.

eif_reduced

the estimated EIF based on the reduced set of covariates.

cross_fit

logical; was cross-fitting used to compute the EIFs? (defaults to TRUE)

sample_split

logical; was sample-splitting used? (defaults to TRUE)

na.rm

logical; should NA's be removed in computation? (defaults to FALSE).

use_square

logical; should we estimate the variance using the square of the EIF (TRUE) or using the cross product (FALSE, the default)

Value

The standard error for the estimated variable importance for the given group of left-out covariates.

Details

See the paper by Williamson, Gilbert, Simon, and Carone for more details on the mathematics behind this function and the definition of the parameter of interest.