Compute standard error estimates based on the estimated influence function for a SPVIM value of interest.
spvim_se(ics, idx = 1, gamma = 1, na_rm = FALSE, use_square = FALSE)the influence function estimates based on the contributions
from sampling observations and sampling subsets: a list of length two
resulting from a call to spvim_ics.
the index of interest
the proportion of the sample size used when sampling subsets
remove NAs?
logical; should we estimate the variance using the square of the EIF (TRUE) or using the cross product (FALSE, the default)
The standard error estimate for the desired SPVIM value
Since the processes for sampling observations and subsets are independent, the variance for a given SPVIM estimator is simply the sum of the variances based on sampling observations and on sampling subsets.
spvim_ics for how the influence functions are estimated.